# pycutils: Small, commonly used python functions

[![PyPI version](https://badge.fury.io/py/pycutils.svg)](https://badge.fury.io/py/pycutils)
![PyPI - Downloads](https://img.shields.io/pypi/dm/pycutils)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
![Tests](https://github.com/CangyuanLi/cutils/actions/workflows/tests.yaml/badge.svg)
![Coverage](https://github.com/CangyuanLi/cutils/blob/master/assets/coverage.svg)

## What is it?

**cutils** is a collection of small but useful and widely applicable functions. Since it only uses the standard library, it is extremely lightweight and portable.

# Usage:

## Installing

The easiest way is to install **cutils** is from PyPI using pip:

```shell
pip install pycutils
```

## Running

```python
import cutils
```
